@@ -1,4 +1,5 @@
 import logging
+import os
 
 from . import databases, topological
 from .core.compound import Compound
@@ -15,3 +16,5 @@ formatter = logging.Formatter(
 handler = logging.StreamHandler()
 handler.setFormatter(formatter)
 logger.addHandler(handler)
+
+os.environ["LC_ALL"] = "C"  # meneco bugfix
