@@ -1,4 +1,4 @@
-from .blast import blast, filter_blast_results
+from .blast import blastp_pipeline, filter_blast_results, tblastn_pipeline
 from .gapfilling import gapfilling
 from .scope import multiple_scopes, scope
 from .treesearch import metabolite_tree_search
