@@ -170,7 +170,7 @@ def export_compartments(model: "Model", sbml_model: libsbml.Model) -> None:
 
 def _add_identifier_annotation(
     element: Union["Compound", "Reaction", "Monomer"],
-    sbml_element: Union[libsbml.Species, libsbml.Reaction],
+    sbml_element: Union[libsbml.Species, libsbml.Reaction, libsbml.GeneProduct],
     db_to_resource: Dict[str, str],
 ) -> None:
     for db, data in element.database_links.items():
@@ -413,13 +413,16 @@ def export_reactions(model: "Model", sbml_model: libsbml.Model) -> None:
             )
 
         # GPR
-        for genes in reaction.monomers.values():
-            names = [_format_name_to_sbml(name, "G_") for name in genes if name in reaction.monomers]
-            if bool(names):
-                gpr = " ".join(names)
+        if (enzrxn := reaction._gpa) is not None:
+            gpa_id = _format_name_to_sbml(enzrxn, "GA_")
+            genes = [_format_name_to_sbml(name, "G_") for name in reaction.monomers[enzrxn]]
+            if len(genes) > 0:
                 gpa: libsbml.GeneProductAssociation = r_fbc.createGeneProductAssociation()
+                _check_libsbml_str_setter(gpa.setId, gpa_id)
+                _check_libsbml_str_setter(gpa.setMetaId, f"meta_{gpa_id}")
+                _check_libsbml_str_setter(gpa.setName, gpa_id)
                 # string_association, usingId=True, addMissingGP=False
-                _check_libsbml_str_bool_bool_setter(gpa.setAssociation, gpr, True, False)
+                _check_libsbml_str_bool_bool_setter(gpa.setAssociation, " and ".join(genes), True, False)
 
         # Database Links
         _add_identifier_annotation(
